#
# spec file for package innoextract
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           innoextract
Version:        1.9
Release:        2.5
Summary:        A tool to extract Inno Setup installers under non-windows systems
License:        Zlib
Group:          Productivity/Archiving/Backup
URL:            http://constexpr.org/innoextract/
Source:         http://constexpr.org/innoextract/files/%{name}-%{version}.tar.gz
Source1:        http://constexpr.org/innoextract/files/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
Patch0:         https://github.com/dscharrer/innoextract/pull/169.patch
BuildRequires:  cmake >= 2.8.0
BuildRequires:  gcc-c++
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(zlib)

%description
Inno Setup is a tool to create installers for Microsoft Windows
applications. Inno Extracts allows to extract such installers under
non-windows systems without running the actual installer using wine. Inno
Extract currently supports installers created by Inno Setup 1.2.10 to
5.4.3.

%prep
%autosetup -p1

%build
%cmake
%make_jobs

%install
%cmake_install

%files
%license LICENSE
%doc CHANGELOG README.md
%{_bindir}/innoextract
%{_mandir}/man1/innoextract.1%{?ext_man}

%changelog
* Sun Apr 28 2024 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * https://github.com/dscharrer/innoextract/pull/169
    Fix build when using boost >= 1.85
  * 169.patch
* Mon Aug 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.9
  * Added preliminary support for Inno Setup 6.1.0.
  * Added support for a modified Inno Setup 5.4.2 variant.
  * Fixed output directory being created for unsupported
    installers.
  * Fixed some safe non-ASCII characters being stripped
    from filenames.
  * Fixed handling of path separators in Japanese and
    Korean installers.
  * Fixed build with newer Boost versions
- Drop patches (included upstream):
  * 0002-CMake-Remove-library-link-checks.patch
  * 0005-CMake-Remove-automatic-re-check-of-libraries.patch
* Fri Oct  4 2019 Martin Hauke <mardnh@gmx.de>
- Add patches: (needed to fix builds for Factory)
  * 0002-CMake-Remove-library-link-checks.patch
  * 0005-CMake-Remove-automatic-re-check-of-libraries.patch
* Mon Sep 16 2019 Martin Hauke <mardnh@gmx.de>
- Udpate to version 1.8
  * Added support for:
    + Inno Setup 6.0.0 installers
    + pre-release Inno Setup 5.6.2 installers used by GOG
    + two modified Inno Setup 5.5.7 variants
    + Inno Setup 1.3.0 to 1.3.23
    + My Inno Setup Extensions installers older than 3.0.6.1
    + modified Inno Setup variants using an alternative setup loader
    magic
    + automatically reading external setup.0 files
  * Encoding for non-Unicode installers is now determined from the
    languages supported by the installer, overridable using the
  - -codepage option
  * Implemented parsing of GOG Galaxy architecture constraints
  * Fixed extracting files from slices larger than 2 GiB with
    32-bit builds
  * Fixed output path for files with absolute paths
    (canonicalization now strips all unsafe characters)
  * Fixed output directory being created even when not extracting
    files
  * Fixed a hang when using the --language option
  * Improved checksum verification for files reconstructed from
    GOG Galaxy file parts
  * Changed header parsing to select the first version without
    warnings and failing that the first without errors
  * Changed filesystem and output encoding to WTF-8 (extended UTF-8)
    to represent broken UTF-16 data
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing libboost_system-devel dependency.
* Fri Aug 24 2018 mpluskal@suse.com
- Be more explicit about requirements
* Thu Aug 23 2018 mardnh@gmx.de
- Update to version 1.7
  * Added support for Inno Setup 5.6.0 installers
  * Added support for new GOG installers with GOG Galaxy file parts
  * Added support for encrypted installers
  * Added --list-sizes and --list-checksums options to print file
    information
  * Adde a --data-version (-V) option to check if an executable is
    an Inno Setup installer
  * Fixed case-sensitivity in parent directory when creating
    subdirectories
  * Fixed issues with names used to load .bin slice files
- Verify source signature
* Wed Mar 14 2018 mpluskal@suse.com
- Drop support for Building on Leap-42
- Modernise spec file with spec-clener
- Use more of cmake macros
- Trim unused build dependency on doxygen
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri Mar 25 2016 mpluskal@suse.com
- Update to 1.6
  * Added support for Inno Setup 5.5.7 (and 5.5.8) installers
  * Added a --collisions=rename-all option
  * Fixed issues with the --collisions=rename option
  * Unsafe characters in special constant strings (ie : in
    {code:…}) are now replaced with $
  * Windows: Fixed progress bar flickering while printing extracted
    filenames
  * Windows binaries: Fixed crash on platforms without AVX support
- Drop upstream patch innoextract-cmake.patch
* Wed Mar 16 2016 mpluskal@suse.com
- Fix build with CMake 3.5
  * innoextract-cmake.patch
* Wed Nov 11 2015 p.drouand@gmail.com
- Update to version 1.5
  * Added support for Inno Setup 5.5.6 installers
  * Added support for a modified Inno Setup 5.5.0 variant
  * Added support for building without iconv (Windows-1252 and
    UTF-16LE only)
  * Added warnings for .bin files that are not part of the installer
  * Added a simple --include (-I) option to filter files
  * Added a --list-languages option to list available languages
  * Added a --exclude-temp (-m) option to not extract temporary files
  * Added a --language-only option to skip language-independent files
  * Added a --collisions option to abort or rename files on collision
  * Added a --default-language option to prefer a language in case of
    file collisions
  * Added a --gog-game-id option to print the GOG.com game ID for
    Galaxy-ready installers
  * Added a --gog (-g) option to extract additional .bin files using
    unrar or unar
  * Fixed handling of spaces in the --data-dir option
  * Fixed an infinite loop with truncated LZMA streams
  * Fixed handling of forward slashes in stored file paths
  * Fixed size display for powers of 1024
  * Fixed loading headers if there are encrypted chunks
  * Fixed file collisions not being handled case-insensitively
  * Files will now be extracted into the same directory even if the
    stored case differs
  * Empty directories are now created correctly when extracting
  * Skipped files in encrypted chunks are now listed individually
  * Temporary files are now marked in file listings
  * Error summary is now written to stderr when using --quiet
  * Colors are now only enabled automatically if $TERM is set to
    something other than "dumb"
  * Improved error and warning messages
  * Build system improvements
  * Debug output can now be enabled separately from debug builds
- Use official project site as Url
- Use official tarball provided by upstream
* Sun Apr 12 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Remove workarounds for unsupported releases
- Use %%cmake macros
- Update dependencies
* Mon Apr  8 2013 pascal.bleser@opensuse.org
- update to 1.4:
  * Fixed issues with the progress bar in sandbox environments
  * Fixed string conversion on systems where libiconv defaults to big-endian
    variants
  * Fixed extracting very large installers with 32-bit innoextract builds
  * Improved handling of invalid encoded strings
  * Improved error messages when input or output files could not be opened
  * The --list command-line option can now combined with --test or --extract
  * The --version command-line option can now be modified with --quiet or
  - -silent
  * Added color output and progress bar support for Windows¿
  * Added support for Unicode filenames under Windows¿
  * Added support for preserving timestamps of extracted files (enabled by
    default)
  * Added a --timestamps (-T) command-line options to control or disable file
    timestamps
  * Added an --output-dir (-d) command-line option to control where files are
    extracted
  * Various bug fixes and tweaks
- changes from 1.3:
  * Fixed --quiet and --silent flags being ignored for some multi-file
    installers output
  * Added a warning when extracting unsupported setup data versions
  * Added support for Inno Setup 5.5.0 installers
* Sun Apr  1 2012 pascal.bleser@opensuse.org
- initial version (1.2)
